@@ -80,19 +80,19 @@
 #' Juergen Gross and bug fixes by Uwe Ligges (2012). nortest: Tests for Normality. R package version
 #' 1.0-2. 
 #' 
-#' \url{http://CRAN.R-project.org/package=nortest}
+#' http://CRAN.R-project.org/package=nortest
 #'
 #' Dallal, G.E. and Wilkinson, L. (1986): An analytic approximation to the distribution of Lilliefors' test for normality. The American Statistician, 40, 294-296.
 #'
 #' Stephens, M.A. (1974): EDF statistics for goodness of fit and some comparisons. Journal of the American Statistical Association, 69, 730-737.
 #'
-#' \url{http://stackoverflow.com/questions/4290081/fitting-data-to-distributions?rq=1}
+#' http://stackoverflow.com/questions/4290081/fitting-data-to-distributions?rq=1
 #'
-#' \url{http://stats.stackexchange.com/questions/45033/can-i-use-kolmogorov-smirnov-test-and-estimate-distribution-parameters}
+#' http://stats.stackexchange.com/questions/45033/can-i-use-kolmogorov-smirnov-test-and-estimate-distribution-parameters
 #'
-#' \url{http://cran.r-project.org/doc/contrib/Ricci-distributions-en.pdf}
+#' http://cran.r-project.org/doc/contrib/Ricci-distributions-en.pdf
 #'
-#' \url{http://cran.r-project.org/doc/contrib/Ricci-distributions-en.pdf}
+#' http://cran.r-project.org/doc/contrib/Ricci-distributions-en.pdf
 #'   
 #' @author Hajk-Georg Drost
 #' @seealso \code{\link{rhScore}}, \code{\link{bootMatrix}}, \code{\link{FlatLineTest}}, \code{\link{PlotPattern}}
@@ -136,16 +136,17 @@ ReductiveHourglassTest <- function(ExpressionSet,
         is.ExpressionSet(ExpressionSet)
         
         if(is.null(modules))
-                stop("Please specify the three modules: early, mid, and late using the argument 'module = list(early = ..., mid = ..., late = ...)'.")
-        
-        if(length(modules) != 3)
-                stop("Please specify three modules: early, mid, and late to perform the ReductiveHourglassTest.")
-        
-        if(length(unlist(modules)) != (dim(ExpressionSet)[2] - 2))
-                stop("The number of stages classified into the three modules does not match the total number of stages stored in the given ExpressionSet.")
+                stop("Please specify the three modules: early, mid, and late using the argument 'module = list(early = ..., mid = ..., late = ...)'.", call. = FALSE)
         
         if(any(table(unlist(modules)) > 1))
-                stop("Intersecting modules are not defined for the ReductiveHourglassTest.")
+                stop("Intersecting modules are not defined for the ReductiveHourglassTest.", call. = FALSE)
+        
+        if(length(modules) != 3)
+                stop("Please specify three modules: early, mid, and late to perform the ReductiveHourglassTest.", call. = FALSE)
+        
+        if(length(unlist(modules)) != (dim(ExpressionSet)[2] - 2))
+                stop("The number of stages classified into the three modules does not match the total number of stages stored in the given ExpressionSet.", call. = FALSE)
+        
         
         nCols <- dim(ExpressionSet)[2]
         score_vector <- vector(mode = "numeric",length = permutations)
