@@ -16,11 +16,28 @@ is.ExpressionSet <- function(ExpressionSet){
         ncols <- dim(ExpressionSet)[2]
         
         d.f_bool <- is.data.frame(ExpressionSet)
+        
+        if (!d.f_bool)
+                stop("ExpressionSet is not a data.frame.")
+        
         age.vector_bool <- is.numeric(ExpressionSet[ , 1])
+        
+        if (!age.vector_bool)
+                stop("The first column of the ExpressionSet needs to store numeric values.")
+        
         gene.vector_bool <- ifelse(is.factor(ExpressionSet[ , 2]),is.character(levels(ExpressionSet[ , 2])),is.character(ExpressionSet[ , 2]))
+        
+        if (!gene.vector_bool)
+                stop("The second column of the ExpressionSet needs to store character values (e.g. gene ids).")
+        
         expression.matrix_bool <- all(sapply(as.matrix(ExpressionSet[ , 3:ncols]), is.numeric))
+        if (!expression.matrix_bool)
+                stop("Columns 3 - ",ncol(ExpressionSet), " need to store numeric values (e.g. expression levels).")
+        
         any.NA.values_bool <- !any(is.na(ExpressionSet))
         
+        if (!any.NA.values_bool)
+                stop("The ExpressionSet cannot contain 'NA' values. Please use na.omit() to remove 'NA' values from the input ExpressionSet.")
         
         if(all(c(d.f_bool,age.vector_bool,gene.vector_bool,expression.matrix_bool,any.NA.values_bool))){
                 return(TRUE)
